#
# spec file for package perl-App-Cmd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name App-Cmd
Name:           perl-App-Cmd
Version:        0.337.0
Release:        1.3
# 0.337 -> normalize -> 0.337.0
%define cpan_version 0.337
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Write command line apps with less suffering
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.13
BuildRequires:  perl(Class::Load) >= 0.06
BuildRequires:  perl(Data::OptList)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(Getopt::Long) >= 2.39
BuildRequires:  perl(Getopt::Long::Descriptive) >= 0.116
BuildRequires:  perl(IO::TieCombine)
BuildRequires:  perl(IPC::Cmd)
BuildRequires:  perl(Module::Pluggable::Object)
BuildRequires:  perl(Pod::Usage) >= 1.61
BuildRequires:  perl(String::RewritePrefix)
BuildRequires:  perl(Sub::Exporter)
BuildRequires:  perl(Sub::Exporter::Util)
BuildRequires:  perl(Sub::Install)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(experimental)
BuildRequires:  perl(parent)
Requires:       perl(Capture::Tiny) >= 0.13
Requires:       perl(Class::Load) >= 0.06
Requires:       perl(Data::OptList)
Requires:       perl(Getopt::Long) >= 2.39
Requires:       perl(Getopt::Long::Descriptive) >= 0.116
Requires:       perl(IO::TieCombine)
Requires:       perl(Module::Pluggable::Object)
Requires:       perl(Pod::Usage) >= 1.61
Requires:       perl(String::RewritePrefix)
Requires:       perl(Sub::Exporter)
Requires:       perl(Sub::Exporter::Util)
Requires:       perl(Sub::Install)
Requires:       perl(experimental)
Requires:       perl(parent)
Provides:       perl(App::Cmd) = %{version}
Provides:       perl(App::Cmd::ArgProcessor) = %{version}
Provides:       perl(App::Cmd::Command) = %{version}
Provides:       perl(App::Cmd::Command::commands) = %{version}
Provides:       perl(App::Cmd::Command::help) = %{version}
Provides:       perl(App::Cmd::Command::version) = %{version}
Provides:       perl(App::Cmd::Plugin) = %{version}
Provides:       perl(App::Cmd::Setup) = %{version}
Provides:       perl(App::Cmd::Simple) = %{version}
Provides:       perl(App::Cmd::Subdispatch) = %{version}
Provides:       perl(App::Cmd::Subdispatch::DashedStyle) = %{version}
Provides:       perl(App::Cmd::Tester) = %{version}
Provides:       perl(App::Cmd::Tester::CaptureExternal) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
App::Cmd is intended to make it easy to write complex command-line
applications without having to think about most of the annoying things
usually involved.

For information on how to start using App::Cmd, see App::Cmd::Tutorial.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Tue Dec 31 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.337.0 (0.337)
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.337     2024-12-30 17:58:25-05:00 America/New_York
  - improve how overriding getopt_conf interacts with unknown options
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.336
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.336     2023-08-26 11:07:01-04:00 America/New_York
  - allow getopt_conf to be provided by user (thanks, Michael McClimon!)
  - add "--version" to Simple commands (thanks, Diab Jerius!)
  - don't point to Plugin docs when they don't exist (thanks, Sawyer!)
* Sun Jan  1 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.335
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.335     2022-12-31 17:00:35-05:00 America/New_York
  - update author contact info
* Sun Jun 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.334
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.334     2021-06-18 22:14:14-04:00 America/New_York
  - add a perl-support block to docs
  - update author contact info
* Mon Mar 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.333
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.333     2021-03-14 15:45:02-04:00 America/New_York
  - dial back required perl to v5.20.0
  0.332     2021-03-12 21:25:38-05:00 America/New_York
  - bump up minimum required perl to the one from 5yr ago
  - make some tests laxer to prep for changes in Getopt::Long::Descriptive
  - the App::Cmd object is constructed and blessed in new before _command
    is called on it (thanks, Lucas Theisen)
* Mon Jul 18 2016 coolo@suse.com
- updated to 0.331
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.331     2016-07-17 15:56:11-04:00 America/New_York
  - documentation improvements (thanks, Davor Cubranic!)
* Sat Oct 24 2015 coolo@suse.com
- updated to 0.330
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.330     2015-10-23 23:21:35-04:00 America/New_York
  - do not add "--help" to global opt spec twice (oops!)
* Sat Oct 10 2015 coolo@suse.com
- updated to 0.329
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.329     2015-10-07 13:01:34-04:00 America/New_York
  - bump required version of Pod::Usage
* Fri Sep  4 2015 coolo@suse.com
- updated to 0.328
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.328     2015-09-03 20:37:50-04:00 America/New_York
  - get command description from Pod by default (Jakob Voss)
  - add a "--help" option to all commands by default (Jakob Voss)
  - add "command_groups" to group commands in listing (Jakob Voss)
  - fix the handling of "exit" in App::Cmd::Tester (Matthew Astley)
  - add 'show_version_cmd' option to enable display of 'version'
    command in command list. (John Anderson)
  - minor documentation improvements (Alberto Simões, rjbs)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.327
  see /usr/share/doc/packages/perl-App-Cmd/Changes
  0.327     2015-02-23 20:05:00-05:00 America/New_York
  - fix behavior of default command under subdispatch (thanks, Stephen
    Caldwell and Diab Jerius!)
  - simplify help and commands commands (thanks, Sergey Romanov)
  - drop some advice that we didn't feel great about (thanks, Karen
    Etheridge)
  0.326     2014-11-30 08:48:29-05:00 America/New_York
    fix the path fix because it was broken by a related fix in EUMM
  0.325     2014-11-29 20:48:34-05:00 America/New_York
    fix a path-related test failure on Win32 (thanks, A. Sinan Unur!)
  0.324     2014-10-20 18:22:25-04:00 America/New_York
    note that `cmd help` can take a subcommand in `cmd help help`
* Mon Dec  9 2013 coolo@suse.com
- updated to 0.323
    fall back to "(unknown)" for command abstract in more cases (thanks,
    Jakob Voss!)
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.322
    require a newer Getopt::Long to avoid --version conflicts
    avoiding getting [undef] in argument list in Simple apps
    add --version support via version command (thanks, Jakob Voss!)
- remove outdated perl-App-Cmd-old_Test-More.patch
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.320
    when answering "Unknown subcommand," the commands list is sent ot
    STDERR (#75652)
    tests for using Params::Validate callback and not getting nasty stack
    trace (thanks, Adam Prime)
    Enable --help option for App::Cmd::Simple (thanks, Ryan Thompson!)
    add the ability to ignore non-commands (Thanks, Kent Fredric!)
    many improvements to tutorial (thanks, mokko!)
* Mon May 28 2012 coolo@suse.com
- updated to 0.318
    App::Cmd::Tester treats undef code as 0 now (thanks, David Golden)
    piles of documentation improvement also by David Golden
* Sat Mar 31 2012 coolo@suse.com
- updated to 0.317
    App::Cmd::Tester now reports exit code 1 for unknown commands, as
    App::Cmd would exit(1) in that case; addresses
    https://rt.cpan.org/Public/Bug/Display.html?id=73084 reported by
    David Golden
* Tue Feb 21 2012 coolo@suse.com
- updated to 0.316
    fix the test of "echo" on Win32 (thanks, Chris Williams)
    totally worthless release made by mistake
    adds App::Cmd::Tester::CaptureExternal to capture output from
    external subcommands (thanks, David Golden)
    if there's no Pod =head1 NAME, a Pod::Weaver-esque #ABSTRACT will be
    respected (thanks, Andreas Hernitscheck)
    don't load Text::Abbrev until it's needed (thanks, Olivier Mengué)
* Sat Nov 19 2011 coolo@suse.com
- update to 0.312
    typo fixes to docs (thanks, Glenn Fowler)
    add the prepare_argv method (thanks, Ingy döt Net)
* Sat Jun  4 2011 lars@linux-schulserver.de
- fix build on distributions with old Test::More module
  ( perl-App-Cmd-old_Test-More.patch )
- add Test::More >= 0.88 to buildrequires
* Wed Apr  6 2011 coolo@novell.com
- updated to 0.311
    require the correct version of Getopt::Long::Descriptive (thanks,
    Glen Hinkle)
* Wed Dec 29 2010 pascal.bleser@opensuse.org
- initial version (0.310)
